LocationService class

Inheritance

Constructors

LocationService(String accessToken, String fromNumberId, Request request)

Properties

accessToken String
The access token for WhatsApp Cloud API authentication.
finalinherited
fromNumberId String
The phone number ID used as the sender in API requests.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
Common headers for WhatsApp API requests.
no setterinherited
request Request
The request utility for making HTTP calls.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createMessageBody(String type, String phoneNumber, Map<String, dynamic> content) Map<String, dynamic>
Helper method to create message body with common fields.
inherited
executeApiCall<T>(Future<Response> apiCall(), T successParser(Map<String, dynamic>)) Future<T>
Common exception handling wrapper for API calls.
inherited
handleResponse<T>(Response response, T successParser(Map<String, dynamic>)) → T
Common error handling for API responses.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendLocation(String phoneNumber, double latitude, double longitude, String? name, String? address) Future<WhatsAppResponse>
sendLocationRequest(String phoneNumber, String text) Future<WhatsAppResponse>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited